@@ -44,7 +44,7 @@ sub open_lzma {
 sub _open_xml_reader {
     my ($xml_info_file) = @_;
 
-    my $reader = XML::LibXML::Reader->new(IO => open_lzma($xml_info_file), huge => 1) or die "cannot read $xml_info_file\n";
+    my $reader = new XML::LibXML::Reader(IO => open_lzma($xml_info_file)) or die "cannot read $xml_info_file\n";
 
     $reader->read;
     $reader->name eq 'media_info' or die "global <media_info> tag not found\n";
@@ -195,6 +195,4 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
-
 =cut
